LIBRARY IEEE;
USE IEEE.STD_LOGIC_1164.ALL;
USE IEEE.STD_LOGIC_ARITH.ALL;
USE IEEE.STD_LOGIC_UNSIGNED.ALL;

entity WRK is
	Port (
		clk		: in	STD_LOGIC;						-- 50 MHz
		btn		: in	STD_LOGIC_VECTOR (2 downto 0);	-- ON := L on input
		led		: out	STD_LOGIC_VECTOR (4 downto 0);	-- L := LED on
		rx		: in	STD_LOGIC;						-- MAX232 R2OUT
		tx		: out	STD_LOGIC;						-- MAX232 T2IN
		digit	: out	STD_LOGIC_VECTOR (3 downto 0);	-- L := digit select
		segment	: out	STD_LOGIC_VECTOR (7 downto 0);	-- L := segment select
		beep	: out	STD_LOGIC;						-- L := buzz on
		lcdrs	: out	STD_LOGIC;						-- LCD Pin 4
		lcdrw	: out	STD_LOGIC;						-- LCD Pin 5
		lcden	: out	STD_LOGIC;						-- LCD Pin 6
		lcd		: out	STD_LOGIC_VECTOR (7 downto 0);	-- LCD D0 Pin 7 - D7 Pin 14
		lcdpsb	: out	STD_LOGIC;						-- LCD Reset Pin 15
		lcdrst	: out	STD_LOGIC						-- LCD Reset Pin 17
	);
end WRK;

architecture Behavioral of WRK is
signal count	:	STD_LOGIC_VECTOR (31 downto 0) := "00000000000000000000000000000000";
signal sel		:	STD_LOGIC_VECTOR (1 downto 0);
signal data		:	STD_LOGIC_VECTOR (3 downto 0);
signal data3	:	STD_LOGIC_VECTOR (3 downto 0);
signal data2	:	STD_LOGIC_VECTOR (3 downto 0);
signal data1	:	STD_LOGIC_VECTOR (3 downto 0);
signal data0	:	STD_LOGIC_VECTOR (3 downto 0);

begin

process (clk) 
begin
	if rising_edge(clk) then
		count <= count + 1;
	end if;
end process;

	lcdrs	<= '0';
	lcdrw	<= '0';
	lcden	<= '0';
	lcd		<= "00000000";
	lcdpsb	<= '0';
	lcdrst	<= '0';
	beep	<= '1';
	tx		<= '0';

	sel <= count (15 downto 14);
	data3 <= count ( 31 downto 28 );
	data2 <= count ( 27 downto 24 );
	data1 <= count ( 23 downto 20 );
	data0 <= count ( 19 downto 16 );
	
	with sel select
	data <=		data0	when "00",
				data1	when "01",
				data2	when "10",
				data3	when "11";

	with sel select
	digit <=	"1110"	when "00",
				"1101"	when "01",
				"1011"	when "10",
				"0111"	when "11";

	with data select
	segment <=	"00111111"	when "0000",
				"00000110"	when "0001",
				"01011011"	when "0010",
				"01001111"	when "0011",
				"01100110"	when "0100",
				"01101111"	when "0101",
				"01111101"	when "0110",
				"00000111"	when "0111",
				"01111111"	when "1000",
				"01101111"	when "1001",
				"01110111"	when "1010",
				"01111100"	when "1011",
				"01011000"	when "1100",
				"01011110"	when "1101",
				"01111001"	when "1110",
				"01110001"	when "1111";

end Behavioral;
